summaryrefslogtreecommitdiff
path: root/src/map/mob.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/map/mob.c')
-rw-r--r--src/map/mob.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/map/mob.c b/src/map/mob.c
index d66307a78..430b32f65 100644
--- a/src/map/mob.c
+++ b/src/map/mob.c
@@ -245,7 +245,7 @@ struct mob_data* mob_spawn_dataset(struct spawn_data *data)
* &1: Apply the summon success chance found in the list (otherwise get any monster from the db)
* &2: Apply a monster check level.
* &4: Selected monster should not be a boss type
* &8: Selected monster must give base exp.
* lv: Mob level to check against
*------------------------------------------*/
int mob_get_random_id(int type, int flag, int lv)
@@ -268,7 +268,7 @@ int mob_get_random_id(int type, int flag, int lv)
(flag&1 && mob->summonper[type] <= rand() % 1000000) ||
(flag&2 && lv < mob->lv) ||
(flag&4 && mob->status.mode&MD_BOSS) ||
- (flag&8 && mob->base_exp < 1)
+ (flag&8 && mob->spawn[0].qty < 1)
) && (i++) < MAX_MOB_DB);
if(i >= MAX_MOB_DB)
@@ -245,7 +245,7 @@ struct mob_data* mob_spawn_dataset(struct spawn_data *data)
* &2: Apply a monster check level.
* &4: Selected monster should not be a boss type
- * &8: Selected monster must give base exp.
+ * &8: Selected monster must have normal spawn.
* lv: Mob level to check against
*------------------------------------------*/